=======================
MemSQL Python Libraries
=======================

This library contains various plugins and wrappers designed by MemSQL
engineers for a couple of important python libraries.

Install
=======

.. code:: bash

    pip install memsql

Testing
=======

.. image:: https://travis-ci.org/memsql/memsql-python.png
    :target: https://travis-ci.org/memsql/memsql-python

Run tests by executing :code:`make test`.
